## Google

- Sign in with account services credentials
- Enable api drive, googleSheet

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install GoogleNb.

```bash
pip install GoogleNb
```

## License

[MIT](https://choosealicense.com/licenses/mit/)